<?php
/**
 * @version		$Id: controller.php 13338 2009-10-27 02:15:55Z ian $
 * @package		Joomla
 * @subpackage	Content
 * @copyright	Copyright (C) 2005 - 2008 Open Source Matters. All rights reserved.
 * @license		GNU/GPL, see LICENSE.php
 * Joomla! is free software. This version may have been modified pursuant to the
 * GNU General Public License, and as distributed it includes or is derivative
 * of works licensed under the GNU General Public License or other free or open
 * source software licenses. See COPYRIGHT.php for copyright notices and
 * details.
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die( 'Restricted access' );

jimport('joomla.application.component.controller');
jimport('joomla.application.component.view');
jimport('joomla.application.component.model');

/**
 * Search Component Controller
 *
 * @package		Joomla
 * @subpackage	Search
 * @since 1.5
 */
class LetsFormsController extends JController
{
	/**
	 * Method to show the search view
	 *
	 * @access	public
	 * @since	1.5
	 */
	function display()
	{
		$viewname = JRequest::getCmd('view');
		$layout = JRequest::getCmd('layout');
		
		if($viewname == 'accounts') {
			$view = $this->getView('accounts', 'html');
			$view->setModel($this->getModel('accounts'), true);
			$view->setModel($this->getModel('members'));
			$view->setLayout($layout);
			$view->display();
		}
		else {
			parent::display();
		}
	}
	
	function transfer() {
		$model = $this->getModel('accounts');
		$error = $model->transfer();
		
		if(is_null($error)) {
			JRequest::setVar( 'layout', 'results' );
		}
		else {
			JRequest::setVar( 'layout', 'error' );
			JRequest::setVar( 'errmsg', $error );
		}
		
		parent::display();
	}

	function register() {
		$model = $this->getModel('members');
		$error = $model->register();
		
		if(is_null($error)) {
			JRequest::setVar( 'layout', 'confirmreg' );
		}
		else {
			JRequest::setVar( 'layout', 'register' );
			JRequest::setVar( 'errmsg', $error );
		}
		
		parent::display();
	}
	
	function adddirentry() {
		$model = $this->getModel('members');
		$error = $model->addDirectoryEntry();
		
		if(is_null($error)) {
			$accessLevel = JRequest::getVar('accessLevel');
			//var_dump($accessLevel);
			if($accessLevel == 'admin') {
				JRequest::setVar( 'layout', 'confirmade' );
			}
			else {
				$type = JRequest::getVar('type');
				$mode = JRequest::getVar('mode');
				if($mode == 'add') {
					$infomsg = "The new " . $type . " has been added to your list";
				}
				else {
					$infomsg = "Your " . $type . " has been updated";
				}
				
				JRequest::setVar( 'layout', 'editdirentries' );
				JRequest::setVar( 'infomsg', $infomsg);
			}
		}
		else {
			JRequest::setVar( 'layout', 'adddirentry' );
			JRequest::setVar( 'errmsg', $error );
		}
		
		parent::display();
	}
	
	function edituser() {
		$model = $this->getModel('members');
		$error = $model->editMember();
		
		if(is_null($error)) {
			JRequest::setVar( 'layout', 'confirmedit' );
		}
		else {
			JRequest::setVar( 'layout', 'editmember' );
			JRequest::setVar( 'errmsg', $error );
		}
		
		parent::display();
	}
	
	function updateentries() {
		$submitAction = JRequest::getVar('fsubmit');
		
		if($submitAction == "Add Offer" || $submitAction == "Add Want") {
			JRequest::setVar( 'layout', 'adddirentry' );
			JRequest::setVar( 'mode', 'add' );
		}
		else if($submitAction == "Delete Selected Offers" || $submitAction == "Delete Selected Wants") {
			$selected = JRequest::getVar('selected');
			if(count($selected) == 0) {
				$error = "You haven't selected any entries to delete";
				JRequest::setVar( 'layout', 'editdirentries' );
				JRequest::setVar( 'errmsg', $error );
			}
			else {
				JRequest::setVar( 'layout', 'confirmdelentries' );
			}
		}
		
		parent::display();
	}
	
	function deleteentries() {
		$model = $this->getModel('members');
		
		$selected = JRequest::getVar('selected');
		if(count($selected) == 0) {
			$error = "You haven't selected any entries to delete";
		}
		else {
			$error = $model->deleteEntries();
		}
		
		if(is_null($error)) {
			$type = JRequest::getVar('type');
			JRequest::setVar( 'layout', 'editdirentries' );
			JRequest::setVar( 'infomsg', "Your selected " . $type . "s have been deleted");
		}
		else {
			JRequest::setVar( 'layout', 'editdirentries' );
			JRequest::setVar( 'errmsg', $error );
		}
		
		parent::display();
	}
	
	function changepasswd() {
		$model = $this->getModel('members');
		$error = $model->changePassword();
		
		if(is_null($error)) {
			JRequest::setVar( 'layout', 'success' );
			JRequest::setVar( 'infomsg', "Your password has been changed");
		}
		else {
			JRequest::setVar( 'layout', 'changepasswd' );
			JRequest::setVar( 'errmsg', $error );
		}
		
		parent::display();
	}
	
	function mailmembers() {
		$model = $this->getModel('members');
		$error = $model->mailMembers();
		
		if(is_null($error)) {
			JRequest::setVar( 'layout', 'success' );
			JRequest::setVar( 'infomsg', "The message has been sent");
		}
		else {
			JRequest::setVar( 'layout', 'mailmembers' );
			JRequest::setVar( 'errmsg', $error );
		}
		
		parent::display();
	}

        function confirmpay() {
		$amount = JRequest::getVar('amount');
		if(empty($amount)) {
			$error = "Please enter the amount you wish to pay";
			JRequest::setVar( 'layout', 'form' );
			JRequest::setVar( 'errmsg', $error );
		}
                else if(!is_numeric($amount)) {
                        $error = "Only numbers are allowed in the amount field. Please enter just the number of nidds you want to pay.";
                        JRequest::setVar( 'amount', '' );
			JRequest::setVar( 'layout', 'form' );
			JRequest::setVar( 'errmsg', $error );
                }
		else {
			JRequest::setVar( 'layout', 'confirm' );
			
		}
		
		$view = $this->getView('accounts', 'html');
		$view->setModel($this->getModel('accounts'), true);
		$view->setModel($this->getModel('members'));
		
		parent::display();
	}
}
